@@ -3,6 +3,7 @@
 import urllib
 
 from pagador import settings
+from pagador.acesso.externo import FormatoDeEnvio
 from pagador.envio.requisicao import Enviar
 from pagador_paypal.extensao.envio import ExpressCheckout
 from pagador_paypal.extensao.seguranca import ParametrosPayPal
@@ -25,7 +26,7 @@ class EnviarPedido(Enviar):
         self.url = "https://api-3t.{}paypal.com/nvp".format(self.sandbox)
         self.grava_identificador = False
         self.headers = {"Content-Type": "application/x-www-form-urlencoded; charset=utf-8"}
-        self.envio_por_querystring = True
+        self.formato_de_envio = FormatoDeEnvio.form_urlencode
 
     @property
     def sandbox(self):
