@@ -1,8 +1,7 @@
 # -*- coding: utf-8 -*-
-import json
 import urllib
 from pagador import settings
-from pagador.envio.serializacao import EntidadeSerializavel, Atributo
+from pagador.acesso.externo import FormatoDeEnvio
 from pagador.retorno.models import SituacaoPedido, Pedido
 from pagador.retorno.registro import RegistroBase
 from pagador_paypal.extensao.envio import ExpressCheckout
@@ -38,7 +37,7 @@ class Registro(RegistroBase):
         self.processa_resposta = True
         self.tipo = tipo
         self._pedido = None
-        self.envio_por_querystring = True
+        self.formato_de_envio = FormatoDeEnvio.form_urlencode
         self.sucesso = tipo == "success"
 
     @property
